API СпамоБорца — СпамоБорец: документация

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »

# API СпамоБорца

Основная задача сервера СпамоБорца - предоставление API для внешних клиентов, с помощью которого клиенты получают доступ к функциональности сервера.

- Транспорт API

- Типы данных
  - Partner
  - Domain
  - Message
  - LogEntry

- Информационные команды
  - Команда sf.info.version

- Команды работы с сообщениями
  - Команда sf.message.input
  - Команда sf.message.firewall.rules.get
  - Команда sf.message.firewall.rules.set
  - Команда sf.message.firewall.rules.check
  - Команда sf.message.log.fetch

- Команды управления доменами
  - Команда sf.domain.list
  - Команда sf.domain.get
  - Команда sf.domain.children

- Команды управления моделью анализа сообщений
  - Команда sf.model.classify
  - Команда sf.model.train

- Клиенты API

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »